@@ -1,9 +1,9 @@
 /*
- * tomoyo_filesystem_test.c
+ * ccs_filesystem_test.c
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2011/09/29
+ * Version: 2.4.0+   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -32,12 +32,10 @@ static void show_prompt(const char *str, const int should_fail)
 #define MS_MOVE         8192
 #endif
 
-static const char *pivot_root_dir = "/sys/kernel/security/";
-
 static int child(void *arg)
 {
 	errno = 0;
-	pivot_root(pivot_root_dir, proc_policy_dir);
+	pivot_root("/sys/kernel/security/", "/sys/kernel/security/tomoyo/");
 	return errno;
 }
 
@@ -169,7 +167,7 @@ static const unsigned char compressed_ext2_image_sample[1350] = {
 int main(int argc, char *argv[])
 {
 	char c = 0;
-	tomoyo_test_init();
+	ccs_test_init();
 
 	/* Test mount(). */
 	{
@@ -200,7 +198,7 @@ int main(int argc, char *argv[])
 			printf("OK: No such device.\n");
 		else
 			printf("BUG: %s\n", strerror(errno));
-		fprintf(domain_fp, "delete allow_mount dev\\011name / "
+		fprintf(domain_fp, "delete file mount dev\\011name / "
 			"fs\\011name 0\n");
 		show_prompt("mount('dev\\011name', '/', 'fs\\011name') ", 1);
 		if (mount("dev\tname", "/", "fs\tname", 0, NULL) == EOF &&
@@ -227,14 +225,14 @@ int main(int argc, char *argv[])
 			printf("BUG: %s\n", strerror(errno));
 		else
 			printf("OK: Success\n");
-		fprintf(domain_fp, "delete allow_mount <NULL> / tmpfs 0\n");
-		fprintf(domain_fp, "allow_mount anydev / tmpfs 0\n");
+		fprintf(domain_fp, "delete file mount <NULL> / tmpfs 0\n");
+		fprintf(domain_fp, "file mount anydev / tmpfs 0\n");
 		show_prompt("mount(NULL, '/', 'tmpfs') ", 0);
 		if (mount(NULL, "/", "tmpfs", 0, NULL))
 			printf("BUG: %s\n", strerror(errno));
 		else
 			printf("OK: Success\n");
-		fprintf(domain_fp, "delete allow_mount anydev / tmpfs 0\n");
+		fprintf(domain_fp, "delete file mount anydev / tmpfs 0\n");
 		set_profile(2, "file::mount");
 		show_prompt("mount(NULL, NULL, 'tmpfs') ", 1);
 		if (mount(NULL, NULL, "tmpfs", 0, NULL))
@@ -282,13 +280,15 @@ int main(int argc, char *argv[])
 		{
 			struct stat sbuf;
 			FILE *fp = NULL;
+			int ret_ignored;
 			snprintf(buf, sizeof(buf) - 1, "zcat - > %s",
 				 dev_ram_path);
 			if (lstat(dev_ram_path, &sbuf) == 0 &&
 			    S_ISBLK(sbuf.st_mode) && MAJOR(sbuf.st_rdev) == 1)
 				fp = popen(buf, "w");
 			if (fp) {
-				fwrite(compressed_ext2_image_sample, 1,
+				ret_ignored =
+					fwrite(compressed_ext2_image_sample, 1,
 				       sizeof(compressed_ext2_image_sample),
 				       fp);
 				pclose(fp);
@@ -327,7 +327,7 @@ int main(int argc, char *argv[])
 			printf("BUG: %s\n", strerror(errno));
 
 		/* Test standard case */
-		fprintf(domain_fp, "allow_mount none /tmp/mount/ tmpfs 0\n");
+		fprintf(domain_fp, "file mount none /tmp/mount/ tmpfs 0\n");
 		show_prompt("mount('none', '/tmp/mount/', 'tmpfs') for "
 			    "'/tmp/mount/'", 0);
 		if (mount("none", "/tmp/mount/", "tmpfs", 0, NULL) == 0)
@@ -335,10 +335,10 @@ int main(int argc, char *argv[])
 		else
 			printf("FAILED: %s\n", strerror(errno));
 		fprintf(domain_fp,
-			"delete allow_mount none /tmp/mount/ tmpfs 0\n");
+			"delete file mount none /tmp/mount/ tmpfs 0\n");
 
 		/* Test device_name with pattern */
-		fprintf(domain_fp, "allow_mount %s\\* /tmp/mount/ ext2 1\n",
+		fprintf(domain_fp, "file mount %s\\* /tmp/mount/ ext2 1\n",
 			dev_ram_path);
 		snprintf(buf, sizeof(buf) - 1, "mount('%s', '/tmp/mount/', "
 			 "'ext2') for '%s\\*'", dev_ram_path, dev_ram_path);
@@ -348,19 +348,19 @@ int main(int argc, char *argv[])
 			printf("OK\n");
 		else
 			printf("FAILED: %s\n", strerror(errno));
-		fprintf(domain_fp, "delete allow_mount %s\\* "
+		fprintf(domain_fp, "delete file mount %s\\* "
 			"/tmp/mount/ ext2 1\n", dev_ram_path);
 
 		/* Test dir_name with pattern */
 		fprintf(domain_fp,
-			"allow_mount none /tmp/\\?\\?\\?\\?\\?/ tmpfs 0\n");
+			"file mount none /tmp/\\?\\?\\?\\?\\?/ tmpfs 0\n");
 		show_prompt("mount('none', '/tmp/mount/', 'tmpfs') for "
 			    "'/tmp/\\?\\?\\?\\?\\?/'", 0);
 		if (mount("none", "/tmp/mount/", "tmpfs", 0, NULL) == 0)
 			printf("OK\n");
 		else
 			printf("FAILED: %s\n", strerror(errno));
-		fprintf(domain_fp, "delete allow_mount none "
+		fprintf(domain_fp, "delete file mount none "
 			"/tmp/\\?\\?\\?\\?\\?/ tmpfs 0\n");
 
 		set_profile(0, "file::mount");
@@ -386,14 +386,14 @@ int main(int argc, char *argv[])
 			printf("OK: Permission denied.\n");
 		else
 			printf("BUG: %s\n", strerror(errno));
-		fprintf(domain_fp, "allow_mount something /tmp/mount/ "
+		fprintf(domain_fp, "file mount something /tmp/mount/ "
 			"--remount 0\n");
 		show_prompt("mount('/tmp/mount/', MS_REMOUNT)", 0);
 		if (mount(NULL, "/tmp/mount/", NULL, MS_REMOUNT, NULL))
 			printf("BUG: %s\n", strerror(errno));
 		else
 			printf("OK: Success.\n");
-		fprintf(domain_fp, "delete allow_mount something /tmp/mount/ "
+		fprintf(domain_fp, "delete file mount something /tmp/mount/ "
 			"--remount 0\n");
 
 		/* Test bind case */
@@ -416,19 +416,19 @@ int main(int argc, char *argv[])
 
 		/* Test remount case */
 		fprintf(domain_fp,
-			"allow_mount any /tmp/mount/ --remount 0\n");
+			"file mount any /tmp/mount/ --remount 0\n");
 		show_prompt("mount('/tmp/mount/', MS_REMOUNT)", 0);
 		if (mount("none", "/tmp/mount/", "tmpfs", MS_REMOUNT, NULL)
 		    == 0)
 			printf("OK\n");
 		else
 			printf("FAILED: %s\n", strerror(errno));
-		fprintf(domain_fp, "delete allow_mount any /tmp/mount/ "
+		fprintf(domain_fp, "delete file mount any /tmp/mount/ "
 			"--remount 0\n");
 
 		/* Test bind case */
 		fprintf(domain_fp,
-			"allow_mount /tmp/mount/ /tmp/mount_bind/ --bind 0\n");
+			"file mount /tmp/mount/ /tmp/mount_bind/ --bind 0\n");
 		show_prompt("mount('/tmp/mount/', '/tmp/mount_bind', MS_BIND)",
 			    0);
 		if (mount("/tmp/mount/", "/tmp/mount_bind/", NULL, MS_BIND,
@@ -438,13 +438,13 @@ int main(int argc, char *argv[])
 			printf("FAILED: %s\n", strerror(errno));
 		set_profile(0, "file::mount");
 		umount("/tmp/mount_bind/");
-		fprintf(domain_fp, "delete allow_mount /tmp/mount/ "
+		fprintf(domain_fp, "delete file mount /tmp/mount/ "
 			"/tmp/mount_bind/ --bind 0\n");
 
 		/* Test move case */
 		set_profile(3, "file::mount");
-		fprintf(domain_fp, "allow_unmount /tmp/mount/\n");
-		fprintf(domain_fp, "allow_mount /tmp/mount/ /tmp/mount_move/ "
+		fprintf(domain_fp, "file unmount /tmp/mount/\n");
+		fprintf(domain_fp, "file mount /tmp/mount/ /tmp/mount_move/ "
 			"--move 0\n");
 		show_prompt("mount('/tmp/mount/', '/tmp/mount_move/', "
 			    "MS_MOVE)", 0);
@@ -455,8 +455,8 @@ int main(int argc, char *argv[])
 			printf("FAILED: %s\n", strerror(errno));
 		set_profile(0, "file::mount");
 		umount("/tmp/mount_move/");
-		fprintf(domain_fp, "delete allow_unmount /tmp/mount/\n");
-		fprintf(domain_fp, "delete allow_mount /tmp/mount/ "
+		fprintf(domain_fp, "delete file unmount /tmp/mount/\n");
+		fprintf(domain_fp, "delete file mount /tmp/mount/ "
 			"/tmp/mount_move/ --move 0\n");
 
 		while (umount("/tmp/mount/") == 0)
@@ -466,22 +466,22 @@ int main(int argc, char *argv[])
 	/* Test umount(). */
 	{
 		/* Test standard case */
-		fprintf(domain_fp, "allow_unmount /tmp/mount/\n");
+		fprintf(domain_fp, "file unmount /tmp/mount/\n");
 
-		set_profile(0, "file::umount");
+		set_profile(0, "file::unmount");
 		mount2("none", "/tmp/mount/", "tmpfs");
-		set_profile(3, "file::umount");
+		set_profile(3, "file::unmount");
 		show_prompt("umount('/tmp/mount/') for '/tmp/mount/'", 0);
 		if (umount("/tmp/mount/") == 0)
 			printf("OK\n");
 		else
 			printf("BUG: %s\n", strerror(errno));
-		fprintf(domain_fp, "delete allow_unmount /tmp/mount/\n");
+		fprintf(domain_fp, "delete file unmount /tmp/mount/\n");
 
-		set_profile(0, "file::umount");
+		set_profile(0, "file::unmount");
 
 		mount2("none", "/tmp/mount/", "tmpfs");
-		set_profile(3, "file::umount");
+		set_profile(3, "file::unmount");
 		show_prompt("umount('/tmp/mount/') for '/tmp/mount/'", 1);
 		if (umount("/tmp/mount/") == EOF && errno == EPERM)
 			printf("OK: Permission denied.\n");
@@ -489,10 +489,10 @@ int main(int argc, char *argv[])
 			printf("FAILED: %s\n", strerror(errno));
 
 		/* Test pattern */
-		fprintf(domain_fp, "allow_unmount /tmp/\\?\\?\\?\\?\\?/\n");
-		set_profile(0, "file::umount");
+		fprintf(domain_fp, "file unmount /tmp/\\?\\?\\?\\?\\?/\n");
+		set_profile(0, "file::unmount");
 		mount2("none", "/tmp/mount/", "tmpfs");
-		set_profile(3, "file::umount");
+		set_profile(3, "file::unmount");
 		show_prompt("umount('/tmp/mount/') for "
 			    "'/tmp/\\?\\?\\?\\?\\?/'", 1);
 		if (umount("/tmp/mount/") == 0)
@@ -500,9 +500,9 @@ int main(int argc, char *argv[])
 		else
 			printf("BUG: %s\n", strerror(errno));
 		fprintf(domain_fp,
-			"delete allow_unmount /tmp/\\?\\?\\?\\?\\?/\n");
+			"delete file unmount /tmp/\\?\\?\\?\\?\\?/\n");
 
-		set_profile(0, "file::umount");
+		set_profile(0, "file::unmount");
 		while (umount("/tmp/mount/") == 0)
 			c++; /* Dummy. */
 	}
@@ -512,7 +512,7 @@ int main(int argc, char *argv[])
 		set_profile(3, "file::chroot");
 
 		/* Test standard case */
-		fprintf(domain_fp, "allow_chroot /tmp/mount/\n");
+		fprintf(domain_fp, "file chroot /tmp/mount/\n");
 		show_prompt("chroot('/tmp/mount/') for '/tmp/mount/'", 0);
 		fflush(stdout);
 		if (fork() == 0) {
@@ -524,7 +524,7 @@ int main(int argc, char *argv[])
 			_exit(0);
 		}
 		wait(NULL);
-		fprintf(domain_fp, "delete allow_chroot /tmp/mount/\n");
+		fprintf(domain_fp, "delete file chroot /tmp/mount/\n");
 
 		show_prompt("chroot('/tmp/mount/') for '/tmp/mount/'", 1);
 		fflush(stdout);
@@ -539,7 +539,7 @@ int main(int argc, char *argv[])
 		wait(NULL);
 
 		/* Test pattern */
-		fprintf(domain_fp, "allow_chroot /tmp/\\?\\?\\?\\?\\?/\n");
+		fprintf(domain_fp, "file chroot /tmp/\\?\\?\\?\\?\\?/\n");
 		show_prompt("chroot('/tmp/mount/') for "
 			    "'/tmp/\\?\\?\\?\\?\\?/'", 0);
 		fflush(stdout);
@@ -553,7 +553,7 @@ int main(int argc, char *argv[])
 		}
 		wait(NULL);
 		fprintf(domain_fp,
-			"delete allow_chroot /tmp/\\?\\?\\?\\?\\?/\n");
+			"delete file chroot /tmp/\\?\\?\\?\\?\\?/\n");
 
 		set_profile(0, "file::chroot");
 	}
@@ -563,10 +563,8 @@ int main(int argc, char *argv[])
 		int error;
 		char *stack = malloc(8192);
 		set_profile(3, "file::pivot_root");
-		fprintf(domain_fp, "allow_pivot_root %s %s\n",
-			 pivot_root_dir, proc_policy_dir);
-		snprintf(stack, 8191, "pivot_root('%s', '%s')", pivot_root_dir,
-			 proc_policy_dir);
+		fprintf(domain_fp, "file pivot_root securityfs:/ securityfs:/tomoyo/\n");
+		snprintf(stack, 8191, "pivot_root('securityfs:/', 'securityfs:/tomoyo/')");
 		show_prompt(stack, 0);
 		{
 			const pid_t pid = clone(child, stack + (8192 / 2),
@@ -581,10 +579,9 @@ int main(int argc, char *argv[])
 		else
 			printf("FAILED: %s\n", strerror(errno));
 
-		fprintf(domain_fp, "delete allow_pivot_root %s %s\n",
-			pivot_root_dir, proc_policy_dir);
-		snprintf(stack, 8191, "pivot_root('%s', '%s')", pivot_root_dir,
-			 proc_policy_dir);
+		fprintf(domain_fp,
+			"delete file pivot_root securityfs:/ securityfs:/tomoyo/\n");
+		snprintf(stack, 8191, "pivot_root('securityfs:/', 'securityfs:/tomoyo/')");
 		show_prompt(stack, 1);
 		{
 			const pid_t pid = clone(child, stack + (8192 / 2),
@@ -600,8 +597,7 @@ int main(int argc, char *argv[])
 			printf("BUG: %s\n", strerror(errno));
 
 		set_profile(2, "file::pivot_root");
-		snprintf(stack, 8191, "pivot_root('%s', '%s')", pivot_root_dir,
-			 proc_policy_dir);
+		snprintf(stack, 8191, "pivot_root('securityfs:/', 'securityfs:/tomoyo/')");
 		show_prompt(stack, 0);
 		{
 			const pid_t pid = clone(child, stack + (8192 / 2),
@@ -626,5 +622,9 @@ int main(int argc, char *argv[])
 	rmdir("/tmp/mount/");
 
 	clear_status();
+	if (0) { /* To suppress "defined but not used" warnings. */
+		write_domain_policy("", 0);
+		write_exception_policy("", 0);
+	}
 	return 0;
 }
