@@ -1,9 +1,9 @@
 /*
- * tomoyo_new_file_test.c
+ * ccs_new_file_test.c
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2011/09/29
+ * Version: 2.4.0+   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -48,46 +48,6 @@ static void make_elf_lib(void)
 
 static const char *policy = "";
 
-#if 0
-static int write_policy(void)
-{
-	FILE *fp;
-	char buffer[8192];
-	int domain_found = 0;
-	int policy_found = 0;
-	memset(buffer, 0, sizeof(buffer));
-	set_profile(0, "file::open");
-	fp = fopen(proc_policy_domain_policy, "r");
-	set_profile(3, "file::open");
-	fprintf(domain_fp, "%s\n", policy);
-	if (!fp) {
-		printf("%s : BUG: policy read failed\n", policy);
-		return 0;
-	}
-	while (fgets(buffer, sizeof(buffer) - 1, fp)) {
-		char *cp = strchr(buffer, '\n');
-		if (cp)
-			*cp = '\0';
-		if (!strncmp(buffer, "<kernel>", 8))
-			domain_found = !strcmp(self_domain, buffer);
-		if (!domain_found)
-			continue;
-		/* printf("<%s>\n", buffer); */
-		if (!strcmp(buffer, policy)) {
-			policy_found = 1;
-			break;
-		}
-	}
-	fclose(fp);
-	if (!policy_found) {
-		printf("%s : BUG: policy write failed\n", policy);
-		return 0;
-	}
-	errno = 0;
-	return 1;
-}
-#endif
-
 static void show_result(int result, char should_success)
 {
 	int err = errno;
@@ -164,6 +124,7 @@ static void stage_file_test(void)
 	struct sockaddr_un addr;
 	struct ifreq ifreq;
 	char *filename = "";
+	int ret_ignored;
 	set_profile(3, "file::execute");
 	set_profile(3, "file::open");
 	set_profile(3, "file::create");
@@ -174,7 +135,6 @@ static void stage_file_test(void)
 	set_profile(3, "file::mksock");
 	set_profile(3, "file::truncate");
 	set_profile(3, "file::symlink");
-	set_profile(3, "file::rewrite");
 	set_profile(3, "file::mkblock");
 	set_profile(3, "file::mkchar");
 	set_profile(3, "file::link");
@@ -185,46 +145,58 @@ static void stage_file_test(void)
 	set_profile(3, "file::ioctl");
 	set_profile(3, "file::chroot");
 	set_profile(3, "file::mount");
-	set_profile(3, "file::umount");
+	set_profile(3, "file::unmount");
 	set_profile(3, "file::pivot_root");
 
-	policy = "allow_read /proc/sys/net/ipv4/ip_local_port_range";
+	policy = "file read proc:/sys/net/ipv4/ip_local_port_range "
+		"task.uid=0 task.gid=0";
 	write_domain_policy(policy, 0);
 	show_result(sysctl(name, 3, buffer, &size, 0, 0), 1);
 	write_domain_policy(policy, 1);
 	show_result(sysctl(name, 3, buffer, &size, 0, 0), 0);
 
-	policy = "allow_write /proc/sys/net/ipv4/ip_local_port_range";
+	policy = "file write proc:/sys/net/ipv4/ip_local_port_range "
+		"task.euid=0 0=0 1-100=10-1000";
 	write_domain_policy(policy, 0);
 	show_result(sysctl(name, 3, 0, 0, buffer, size), 1);
 	write_domain_policy(policy, 1);
 	show_result(sysctl(name, 3, 0, 0, buffer, size), 0);
 
-	policy = "allow_read/write /proc/sys/net/ipv4/ip_local_port_range";
+	policy = "file read proc:/sys/net/ipv4/ip_local_port_range "
+		"1!=10-100";
+	write_domain_policy(policy, 0);
+	policy = "file write proc:/sys/net/ipv4/ip_local_port_range "
+		"1!=10-100";
 	write_domain_policy(policy, 0);
 	show_result(sysctl(name, 3, buffer, &size, buffer, size), 1);
+	policy = "file read proc:/sys/net/ipv4/ip_local_port_range "
+		"1!=10-100";
+	write_domain_policy(policy, 1);
+	policy = "file write proc:/sys/net/ipv4/ip_local_port_range "
+		"1!=10-100";
 	write_domain_policy(policy, 1);
 	show_result(sysctl(name, 3, buffer, &size, buffer, size), 0);
 
-	policy = "allow_read /tmp/uselib";
+	policy = "file read /tmp/uselib "
+		"path1.uid=0 path1.parent.uid=0 10=10-100";
 	write_domain_policy(policy, 0);
 	show_result(uselib("/tmp/uselib"), 1);
 	write_domain_policy(policy, 1);
 	show_result(uselib("/tmp/uselib"), 0);
 
-	policy = "allow_execute /bin/true";
+	policy = "file execute /bin/true task.uid!=10 path1.parent.uid=0";
 	write_domain_policy(policy, 0);
 	fflush(stdout);
 	fflush(stderr);
-	pipe(pipe_fd);
+	ret_ignored = pipe(pipe_fd);
 	if (fork() == 0) {
 		execl("/bin/true", "/bin/true", NULL);
 		err = errno;
-		write(pipe_fd[1], &err, sizeof(err));
+		ret_ignored = write(pipe_fd[1], &err, sizeof(err));
 		_exit(0);
 	}
 	close(pipe_fd[1]);
-	read(pipe_fd[0], &err, sizeof(err));
+	ret_ignored = read(pipe_fd[0], &err, sizeof(err));
 	close(pipe_fd[0]);
 	wait(NULL);
 	errno = err;
@@ -232,21 +204,22 @@ static void stage_file_test(void)
 	write_domain_policy(policy, 1);
 	fflush(stdout);
 	fflush(stderr);
-	pipe(pipe_fd);
+	ret_ignored = pipe(pipe_fd);
 	if (fork() == 0) {
 		execl("/bin/true", "/bin/true", NULL);
 		err = errno;
-		write(pipe_fd[1], &err, sizeof(err));
+		ret_ignored = write(pipe_fd[1], &err, sizeof(err));
 		_exit(0);
 	}
 	close(pipe_fd[1]);
-	read(pipe_fd[0], &err, sizeof(err));
+	ret_ignored = read(pipe_fd[0], &err, sizeof(err));
 	close(pipe_fd[0]);
 	wait(NULL);
 	errno = err;
 	show_result(err ? EOF : 0, 0);
 
-	policy = "allow_read /dev/null";
+	policy = "file read /dev/null path1.type=char path1.dev_major=1 "
+		"path1.dev_minor=3";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDONLY);
 	show_result(fd, 1);
@@ -258,7 +231,7 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_read /dev/null";
+	policy = "file read /dev/null path1.perm=0666";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDONLY);
 	show_result(fd, 1);
@@ -270,7 +243,7 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_read /dev/null";
+	policy = "file read /dev/null path1.perm!=0777";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDONLY);
 	show_result(fd, 1);
@@ -282,7 +255,12 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_read /dev/null";
+	policy = "file read /dev/null path1.perm=owner_read "
+		"path1.perm=owner_write path1.perm!=owner_execute "
+		"path1.perm=group_read path1.perm=group_write "
+		"path1.perm!=group_execute path1.perm=others_read "
+		"path1.perm=others_write path1.perm!=others_execute "
+		"path1.perm!=setuid path1.perm!=setgid path1.perm!=sticky";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDONLY);
 	show_result(fd, 1);
@@ -295,7 +273,9 @@ static void stage_file_test(void)
 		close(fd);
 
 	set_profile(3, "file::mkfifo");
-	policy = "allow_mkfifo /tmp/mknod_fifo_test 0644";
+	policy = "file mkfifo /tmp/mknod_fifo_test 0644 "
+		"path1.parent.perm=01777 path1.parent.perm=sticky "
+		"path1.parent.uid=0 path1.parent.gid=0";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mknod_fifo_test";
 	show_result(mknod(filename, S_IFIFO | 0644, 0), 1);
@@ -308,7 +288,9 @@ static void stage_file_test(void)
 	filename = "/dev/null";
 	stat(filename, &sbuf);
 	snprintf(pbuffer, sizeof(pbuffer) - 1,
-		 "allow_write %s", filename);
+		 "file write %s path1.major=%u path1.minor=%u",
+		 filename, (unsigned int) MAJOR(sbuf.st_dev),
+		 (unsigned int) MINOR(sbuf.st_dev));
 	policy = pbuffer;
 	write_domain_policy(policy, 0);
 	fd = open(filename, O_WRONLY);
@@ -321,7 +303,8 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_read/write /tmp/fifo";
+	policy = "file read /tmp/fifo path1.type=fifo\t"
+		"file write /tmp/fifo path1.type=fifo";
 	mkfifo2("/tmp/fifo");
 	write_domain_policy(policy, 0);
 	fd = open("/tmp/fifo", O_RDWR);
@@ -334,7 +317,7 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_read /dev/null";
+	policy = "file read /dev/null path1.parent.ino=path1.parent.ino";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDONLY);
 	show_result(fd, 1);
@@ -346,7 +329,7 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_write /dev/null";
+	policy = "file write /dev/null path1.uid=path1.gid";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_WRONLY);
 	show_result(fd, 1);
@@ -358,7 +341,8 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_read/write /dev/null";
+	policy = "file read /dev/null task.uid=path1.parent.uid\t"
+		"file write /dev/null task.uid=path1.parent.uid";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDWR);
 	show_result(fd, 1);
@@ -370,9 +354,10 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "allow_create /tmp/open_test 0644";
+	policy = "file create /tmp/open_test 0644 "
+		"path1.parent.uid=task.uid";
 	write_domain_policy(policy, 0);
-	policy = "allow_write /tmp/open_test";
+	policy = "file write /tmp/open_test path1.parent.uid=0";
 	write_domain_policy(policy, 0);
 	fd = open("/tmp/open_test", O_WRONLY | O_CREAT | O_EXCL, 0644);
 	show_result(fd, 1);
@@ -386,12 +371,13 @@ static void stage_file_test(void)
 		close(fd);
 	unlink2("/tmp/open_test");
 
-	policy = "allow_create /tmp/open_test 0644";
+	policy = "file create /tmp/open_test 0644 "
+		"path1.parent.uid=task.uid";
 	write_domain_policy(policy, 1);
 
-	policy = "allow_write /tmp/open_test";
+	policy = "file write /tmp/open_test task.uid=0 path1.ino!=0";
 	write_domain_policy(policy, 0);
-	policy = "allow_create /tmp/open_test 0644";
+	policy = "file create /tmp/open_test 0644 0=0";
 	write_domain_policy(policy, 0);
 	fd = open("/tmp/open_test", O_WRONLY | O_CREAT | O_EXCL, 0644);
 	show_result(fd, 1);
@@ -404,15 +390,15 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 	unlink2("/tmp/open_test");
-	policy = "allow_write /tmp/open_test";
+	policy = "file write /tmp/open_test task.uid=0 path1.ino!=0";
 	write_domain_policy(policy, 1);
 
 	filename = "/tmp/truncate_test";
 	create2(filename);
 
-	policy = "allow_truncate /tmp/truncate_test";
+	policy = "file truncate /tmp/truncate_test task.uid=path1.uid";
 	write_domain_policy(policy, 0);
-	policy = "allow_write /tmp/truncate_test";
+	policy = "file write /tmp/truncate_test 1!=100-1000000";
 	write_domain_policy(policy, 0);
 	fd = open(filename, O_WRONLY | O_TRUNC);
 	show_result(fd, 1);
@@ -423,12 +409,13 @@ static void stage_file_test(void)
 	show_result(fd, 0);
 	if (fd != EOF)
 		close(fd);
-	policy = "allow_truncate /tmp/truncate_test";
+	policy = "file truncate /tmp/truncate_test "
+		"task.uid=path1.uid";
 	write_domain_policy(policy, 1);
 
-	policy = "allow_write /tmp/truncate_test";
+	policy = "file write /tmp/truncate_test";
 	write_domain_policy(policy, 0);
-	policy = "allow_truncate /tmp/truncate_test";
+	policy = "file truncate /tmp/truncate_test";
 	write_domain_policy(policy, 0);
 	fd = open(filename, O_WRONLY | O_TRUNC);
 	show_result(fd, 1);
@@ -439,16 +426,16 @@ static void stage_file_test(void)
 	show_result(fd, 0);
 	if (fd != EOF)
 		close(fd);
-	policy = "allow_write /tmp/truncate_test";
+	policy = "file write /tmp/truncate_test";
 	write_domain_policy(policy, 1);
 
-	policy = "allow_truncate /tmp/truncate_test";
+	policy = "file truncate /tmp/truncate_test";
 	write_domain_policy(policy, 0);
 	show_result(truncate(filename, 0), 1);
 	write_domain_policy(policy, 1);
 	show_result(truncate(filename, 0), 0);
 
-	policy = "allow_truncate /tmp/truncate_test";
+	policy = "file truncate /tmp/truncate_test";
 	write_domain_policy(policy, 0);
 	set_profile(0, "file::open");
 	fd = open(filename, O_WRONLY);
@@ -461,7 +448,7 @@ static void stage_file_test(void)
 
 	unlink2(filename);
 
-	policy = "allow_create /tmp/mknod_reg_test 0644";
+	policy = "file create /tmp/mknod_reg_test 0644";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mknod_reg_test";
 	show_result(mknod(filename, S_IFREG | 0644, 0), 1);
@@ -469,7 +456,7 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(mknod(filename, S_IFREG | 0644, 0), 0);
 
-	policy = "allow_mkchar /tmp/mknod_chr_test 0644 1 3";
+	policy = "file mkchar /tmp/mknod_chr_test 0644 1 3";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mknod_chr_test";
 	show_result(mknod(filename, S_IFCHR | 0644, MKDEV(1, 3)), 1);
@@ -477,7 +464,7 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(mknod(filename, S_IFCHR | 0644, MKDEV(1, 3)), 0);
 
-	policy = "allow_mkblock /tmp/mknod_blk_test 0644 1 0";
+	policy = "file mkblock /tmp/mknod_blk_test 0644 1 0";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mknod_blk_test";
 	show_result(mknod(filename, S_IFBLK | 0644, MKDEV(1, 0)), 1);
@@ -485,7 +472,7 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(mknod(filename, S_IFBLK | 0644, MKDEV(1, 0)), 0);
 
-	policy = "allow_mkfifo /tmp/mknod_fifo_test 0644";
+	policy = "file mkfifo /tmp/mknod_fifo_test 0644";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mknod_fifo_test";
 	show_result(mknod(filename, S_IFIFO | 0644, 0), 1);
@@ -493,7 +480,7 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(mknod(filename, S_IFIFO | 0644, 0), 0);
 
-	policy = "allow_mksock /tmp/mknod_sock_test 0644";
+	policy = "file mksock /tmp/mknod_sock_test 0644";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mknod_sock_test";
 	show_result(mknod(filename, S_IFSOCK | 0644, 0), 1);
@@ -501,7 +488,7 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(mknod(filename, S_IFSOCK | 0644, 0), 0);
 
-	policy = "allow_mkdir /tmp/mkdir_test/ 0600";
+	policy = "file mkdir /tmp/mkdir_test/ 0600";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/mkdir_test";
 	show_result(mkdir(filename, 0600), 1);
@@ -509,7 +496,7 @@ static void stage_file_test(void)
 	rmdir2(filename);
 	show_result(mkdir(filename, 0600), 0);
 
-	policy = "allow_rmdir /tmp/rmdir_test/";
+	policy = "file rmdir /tmp/rmdir_test/";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/rmdir_test";
 	mkdir2(filename);
@@ -519,7 +506,7 @@ static void stage_file_test(void)
 	show_result(rmdir(filename), 0);
 	rmdir2(filename);
 
-	policy = "allow_unlink /tmp/unlink_test";
+	policy = "file unlink /tmp/unlink_test";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/unlink_test";
 	create2(filename);
@@ -529,7 +516,7 @@ static void stage_file_test(void)
 	show_result(unlink(filename), 0);
 	unlink2(filename);
 
-	policy = "allow_symlink /tmp/symlink_source_test";
+	policy = "file symlink /tmp/symlink_source_test";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/symlink_source_test";
 	show_result(symlink("/tmp/symlink_dest_test", filename), 1);
@@ -537,7 +524,8 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(symlink("/tmp/symlink_dest_test", filename), 0);
 
-	policy = "allow_symlink /tmp/symlink_source_test";
+	policy = "file symlink /tmp/symlink_source_test "
+		"symlink.target=\"/tmp/symlink_\\*_test\"";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/symlink_source_test";
 	show_result(symlink("/tmp/symlink_dest_test", filename), 1);
@@ -545,7 +533,8 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(symlink("/tmp/symlink_dest_test", filename), 0);
 
-	policy = "allow_symlink /tmp/symlink_source_test";
+	policy = "file symlink /tmp/symlink_source_test "
+		"task.uid=0 symlink.target=\"/tmp/symlink_\\*_test\"";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/symlink_source_test";
 	show_result(symlink("/tmp/symlink_dest_test", filename), 1);
@@ -553,7 +542,8 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(symlink("/tmp/symlink_dest_test", filename), 0);
 
-	policy = "allow_symlink /tmp/symlink_source_test";
+	policy = "file symlink /tmp/symlink_source_test "
+		"symlink.target!=\"\\*\"";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/symlink_source_test";
 	show_result(symlink("/tmp/symlink_dest_test", filename), 1);
@@ -561,15 +551,16 @@ static void stage_file_test(void)
 	unlink2(filename);
 	show_result(symlink("/tmp/symlink_dest_test", filename), 0);
 
-	policy = "allow_symlink /tmp/symlink_source_test";
+	policy = "file symlink /tmp/symlink_source_test "
+		"symlink.target!=\"/tmp/symlink_\\*_test\"";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/symlink_source_test";
-	show_result(symlink("/tmp/symlink_dest_test", filename), 1);
+	show_result(symlink("/tmp/symlink_dest_test", filename), 0);
 	write_domain_policy(policy, 1);
 	unlink2(filename);
 	show_result(symlink("/tmp/symlink_dest_test", filename), 0);
 
-	policy = "allow_link /tmp/link_source_test /tmp/link_dest_test";
+	policy = "file link /tmp/link_source_test /tmp/link_dest_test";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/link_source_test";
 	create2(filename);
@@ -579,7 +570,7 @@ static void stage_file_test(void)
 	show_result(link(filename, "/tmp/link_dest_test"), 0);
 	unlink2(filename);
 
-	policy = "allow_rename /tmp/rename_source_test /tmp/rename_dest_test";
+	policy = "file rename /tmp/rename_source_test /tmp/rename_dest_test";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/rename_source_test";
 	create2(filename);
@@ -590,7 +581,7 @@ static void stage_file_test(void)
 	show_result(rename(filename, "/tmp/rename_dest_test"), 0);
 	unlink2(filename);
 
-	policy = "allow_mksock /tmp/socket_test 0755";
+	policy = "file mksock /tmp/socket_test 0755";
 	write_domain_policy(policy, 0);
 	filename = "/tmp/socket_test";
 	memset(&addr, 0, sizeof(addr));
@@ -608,62 +599,10 @@ static void stage_file_test(void)
 		    0);
 	if (fd != EOF)
 		close(fd);
-
-	filename = "/tmp/rewrite_test";
-	create2(filename);
-	policy = "allow_read/write /tmp/rewrite_test";
-	write_domain_policy(policy, 0);
-	write_exception_policy("deny_rewrite /tmp/rewrite_test", 0);
-	policy = "allow_truncate /tmp/rewrite_test";
-	write_domain_policy(policy, 0);
-
-	fd = open(filename, O_RDONLY);
-	show_result(fd, 1);
-	if (fd != EOF)
-		close(fd);
-
-	fd = open(filename, O_WRONLY | O_APPEND);
-	show_result(fd, 1);
-	if (fd != EOF)
-		close(fd);
-
-	fd = open(filename, O_WRONLY);
-	show_result(fd, 0);
-	if (fd != EOF)
-		close(fd);
-
-	fd = open(filename, O_WRONLY | O_TRUNC);
-	show_result(fd, 0);
-	if (fd != EOF)
-		close(fd);
-
-	fd = open(filename, O_WRONLY | O_TRUNC | O_APPEND);
-	show_result(fd, 0);
-	if (fd != EOF)
-		close(fd);
-
-	show_result(truncate(filename, 0), 0);
-
-	set_profile(0, "file::open");
-	fd = open(filename, O_WRONLY | O_APPEND);
-	set_profile(3, "file::open");
-	show_result(ftruncate(fd, 0), 0);
-
-	show_result(fcntl(fd, F_SETFL,
-			  fcntl(fd, F_GETFL) & ~O_APPEND), 0);
-	if (fd != EOF)
-		close(fd);
-
-	write_domain_policy(policy, 1);
-
-	policy = "allow_read/write /tmp/rewrite_test";
-	write_domain_policy(policy, 1);
-	write_exception_policy("deny_rewrite /tmp/rewrite_test", 1);
-
 	unlink2(filename);
 
-	policy = "allow_ioctl socket:[family=2:type=2:protocol=17] "
-		"35122-35124";
+	policy = "file ioctl socket:[family=2:type=2:protocol=17] "
+		"35122-35124 task.uid=0";
 	write_domain_policy(policy, 0);
 	fd = socket(PF_INET, SOCK_DGRAM, IPPROTO_IP);
 	memset(&ifreq, 0, sizeof(ifreq));
@@ -671,7 +610,7 @@ static void stage_file_test(void)
 		 "lo");
 	show_result(ioctl(fd, 35123, &ifreq), 1);
 	write_domain_policy(policy, 1);
-	policy = "allow_ioctl "
+	policy = "file ioctl "
 		"socket:[family=2:type=2:protocol=17] 0-35122";
 	write_domain_policy(policy, 0);
 	show_result(ioctl(fd, 35123, &ifreq), 0);
@@ -682,14 +621,16 @@ static void stage_file_test(void)
 
 int main(int argc, char *argv[])
 {
-	tomoyo_test_init();
+	ccs_test_init();
 	make_elf_lib();
 	fprintf(domain_fp, "%s /bin/true\n", self_domain);
 	fprintf(domain_fp, "use_profile 255\n");
 	fprintf(domain_fp, "select pid=%u\n", pid);
-	//fprintf(profile_fp, "255-PREFERENCE::audit={ max_reject_log=1024 }\n");
+	fprintf(profile_fp, "255-PREFERENCE={ max_reject_log=1024 }\n");
 	stage_file_test();
 	fprintf(domain_fp, "use_profile 0\n");
 	clear_status();
+	if (0) /* To suppress "defined but not used" warnings. */
+		write_exception_policy("", 0);
 	return 0;
 }
