@@ -1,9 +1,9 @@
 /*
- * tomoyo_policy_io_test.c
+ * ccs_policy_io_test.c
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2011/09/29
+ * Version: 2.4.0+   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -39,6 +39,9 @@ static void try_io(const char *policy, const char should_success)
 		char *cp = strchr(buffer, '\n');
 		if (cp)
 			*cp = '\0';
+		if (!strcmp(policy_file, proc_policy_exception_policy) &&
+		    !strncmp(buffer, "<kernel> ", 9))
+			memmove(buffer, buffer + 9, strlen(buffer + 9) + 1);
 		if (!strcmp(buffer, policy)) {
 			policy_found = 1;
 			break;
@@ -65,62 +68,58 @@ static void stage_policy_io_test(void)
 	policy_file = proc_policy_domain_policy;
 	policy_fp = domain_fp;
 	for (i = 0; i < 3; i++) {
-		try_io("allow_chroot /", 1);
-		try_io("allow_chroot ", 0);
-		try_io("allow_chroot /mnt0/", 1);
-		try_io("allow_chroot /var1/chroot2/", 1);
-		try_io("allow_chroot /mnt0/", 1);
-		try_io("allow_chroot /mnt0/", 1);
-		try_io("allow_chroot /mnt0/", 1);
-		try_io("allow_chroot /mnt\\?\\*/", 1);
-		try_io("allow_chroot /mnt\\?\\*/", 1);
-		try_io("allow_unmount /", 1);
-		try_io("allow_unmount /sys1/", 1);
-		try_io("allow_unmount /initrd2/", 1);
-		try_io("allow_unmount /initrd/dev3/", 1);
-		try_io("allow_unmount /initrd/\\*\\+/", 1);
-		try_io("allow_unmount /initrd/\\@\\*/", 1);
-		try_io("allow_unmount /initrd2/", 1);
-		try_io("allow_pivot_root / /proc3/", 1);
-		try_io("allow_pivot_root /sys5/ /proc3/", 1);
-		try_io("allow_pivot_root /sys/", 0);
-		try_io("allow_pivot_root *", 0);
-		try_io("allow_pivot_root /sys5/ /proc3/", 1);
-		try_io("allow_mount / / --bind 0xD", 1);
-		try_io("allow_mount / / --move 0xF", 1);
-		try_io("allow_mount / --remount", 0);
-		try_io("allow_mount /", 0);
-		try_io("allow_mount none /tmp/ tmpfs 0x1", 1);
-		try_io("allow_mount none /tmp/ tmpfs", 0);
-		try_io("allow_mount none /tmp/ nonexistent 0x0", 1);
-		try_io("allow_mount none /proc/ proc 0x0", 1);
-		try_io("allow_mount none /selinux/ selinuxfs 0x0", 1);
-		try_io("allow_mount /proc/bus/usb /proc/bus/usb/ usbfs 0x0", 1);
-		try_io("allow_mount none /dev/pts/ devpts 0x0", 1);
-		try_io("allow_mount any / --remount 0xC00", 1);
-		try_io("allow_mount /dev/sda1 /boot/ ext3 0xC00", 1);
-		try_io("allow_mount none /dev/shm/ tmpfs 0x0", 1);
-		try_io("allow_mount none /proc/sys/fs/binfmt_misc/ binfmt_misc "
+		try_io("file chroot /", 1);
+		try_io("file chroot ", 0);
+		try_io("file chroot /mnt0/", 1);
+		try_io("file chroot /var1/chroot2/", 1);
+		try_io("file chroot /mnt0/", 1);
+		try_io("file chroot /mnt0/", 1);
+		try_io("file chroot /mnt0/", 1);
+		try_io("file chroot /mnt\\?\\*/", 1);
+		try_io("file chroot /mnt\\?\\*/", 1);
+		try_io("file unmount /", 1);
+		try_io("file unmount /sys1/", 1);
+		try_io("file unmount /initrd2/", 1);
+		try_io("file unmount /initrd/dev3/", 1);
+		try_io("file unmount /initrd/\\*\\+/", 1);
+		try_io("file unmount /initrd/\\@\\*/", 1);
+		try_io("file unmount /initrd2/", 1);
+		try_io("file pivot_root / /proc3/", 1);
+		try_io("file pivot_root /sys5/ /proc3/", 1);
+		try_io("file pivot_root /sys/", 0);
+		try_io("file pivot_root *", 0);
+		try_io("file pivot_root /sys5/ /proc3/", 1);
+		try_io("file mount / / --bind 0xD", 1);
+		try_io("file mount / / --move 0xF", 1);
+		try_io("file mount / --remount", 0);
+		try_io("file mount /", 0);
+		try_io("file mount none /tmp/ tmpfs 0x1", 1);
+		try_io("file mount none /tmp/ tmpfs", 0);
+		try_io("file mount none /tmp/ nonexistent 0x0", 1);
+		try_io("file mount none /proc/ proc 0x0", 1);
+		try_io("file mount none /selinux/ selinuxfs 0x0", 1);
+		try_io("file mount /proc/bus/usb proc:/bus/usb/ usbfs 0x0", 1);
+		try_io("file mount none /dev/pts/ devpts 0x0", 1);
+		try_io("file mount any / --remount 0xC00", 1);
+		try_io("file mount /dev/sda1 /boot/ ext3 0xC00", 1);
+		try_io("file mount none /dev/shm/ tmpfs 0x0", 1);
+		try_io("file mount none proc:/sys/fs/binfmt_misc/ binfmt_misc "
 		       "0x0", 1);
-		try_io("allow_mount none /proc/sys/fs/binfmt_misc/ binfmt_misc "
+		try_io("file mount none proc:/sys/fs/binfmt_misc/ binfmt_misc "
 		       "0x0 0x1", 0);
-		try_io("allow_mount none /proc/sys/fs/binfmt_misc/ tmpfs "
+		try_io("file mount none proc:/sys/fs/binfmt_misc/ tmpfs "
 		       "binfmt_misc 0x0", 0);
-		try_io("allow_mount /proc/bus/usb /proc/bus/usb/ usbfs 0x0", 1);
+		try_io("file mount /proc/bus/usb proc:/bus/usb/ usbfs 0x0", 1);
 	}
 	policy_file = proc_policy_exception_policy;
 	policy_fp = exception_fp;
 	for (i = 0; i < 3; i++) {
-		try_io("allow_read /tmp/abc", 1);
-		try_io("allow_read /tmp/abc\\*", 1);
-		try_io("allow_read abc", 1);
-		try_io("allow_read /tmp/abc/", 1);
-		try_io("allow_read", 0);
-		try_io("allow_read *", 1);
-		try_io("file_pattern /\\*\\*\\*", 1);
-		try_io("file_pattern /abc", 1);
-		try_io("file_pattern /abc /def", 0);
-		try_io("file_pattern abcdef", 1);
+		try_io("acl_group 0 file read /tmp/abc", 1);
+		try_io("acl_group 0 file read /tmp/abc\\*", 1);
+		try_io("acl_group 0 file read abc", 1);
+		try_io("acl_group 0 file read /tmp/abc/", 1);
+		try_io("acl_group 0 file read", 0);
+		try_io("acl_group 0 file read *", 1);
 		try_io("path_group TEST /", 1);
 		try_io("path_group TEST /boo", 1);
 		try_io("path_group TEST /bar", 1);
@@ -137,46 +136,40 @@ static void stage_policy_io_test(void)
 		try_io("path_group TEST3 /bar", 1);
 		try_io("path_group TEST3 boo", 1);
 		try_io("path_group TEST3 boo/", 1);
-		try_io("deny_rewrite /", 1);
-		try_io("deny_rewrite /foo", 1);
-		try_io("deny_rewrite /\\*", 1);
-		try_io("deny_rewrite /\\:", 0);
-		try_io("deny_rewrite / /", 0);
-		try_io("deny_rewrite @/TEST", 1);
 		try_io("aggregator /boo/\\* /BOO", 1);
 		try_io("aggregator /boo/\\* /BOO\\*", 0);
 		try_io("aggregator /boo/\\*/ /BOO", 1);
 		try_io("aggregator /boo/\\* /BOO/", 1);
-		try_io("keep_domain <kernel>", 1);
-		try_io("keep_domain <kernel> /sbin/init", 1);
-		try_io("keep_domain <kernel> foo", 0);
-		try_io("keep_domain <kernel> \\*", 0);
-		try_io("keep_domain /ssh", 1);
-		try_io("keep_domain /ssh /foo", 0);
+		try_io("keep_domain any from <kernel>", 1);
+		try_io("keep_domain any from <kernel> /sbin/init", 1);
+		try_io("keep_domain any from <kernel> foo", 0);
+		try_io("keep_domain any from <kernel> \\*", 0);
+		try_io("keep_domain any from /ssh", 1);
+		try_io("keep_domain any from /ssh /foo", 0);
 		try_io("keep_domain /foo from <kernel>", 1);
 		try_io("keep_domain /foo from <kernel> /sbin/init", 1);
 		try_io("keep_domain from <kernel> /sbin/init", 0);
 		try_io("keep_domain \\* from <kernel> /sbin/init", 0);
-		try_io("no_keep_domain <kernel>", 1);
-		try_io("no_keep_domain <kernel> /sbin/init", 1);
-		try_io("no_keep_domain <kernel> foo", 0);
-		try_io("no_keep_domain <kernel> \\*", 0);
-		try_io("no_keep_domain /ssh", 1);
-		try_io("no_keep_domain /ssh /foo", 0);
+		try_io("no_keep_domain any from <kernel>", 1);
+		try_io("no_keep_domain any from <kernel> /sbin/init", 1);
+		try_io("no_keep_domain any from <kernel> foo", 0);
+		try_io("no_keep_domain any from <kernel> \\*", 0);
+		try_io("no_keep_domain any from /ssh", 1);
+		try_io("no_keep_domain any from /ssh /foo", 0);
 		try_io("no_keep_domain /foo from <kernel>", 1);
 		try_io("no_keep_domain /foo from <kernel> /sbin/init", 1);
 		try_io("no_keep_domain from <kernel> /sbin/init", 0);
 		try_io("no_keep_domain \\* from <kernel> /sbin/init", 0);
-		try_io("initialize_domain /foo", 1);
-		try_io("initialize_domain /\\*", 1);
-		try_io("initialize_domain /foo /bar", 0);
+		try_io("initialize_domain /foo from any", 1);
+		try_io("initialize_domain /\\* from any", 1);
+		try_io("initialize_domain /foo /bar from any", 0);
 		try_io("initialize_domain /foo from /bar", 1);
 		try_io("initialize_domain /foo from <kernel> /bar", 1);
 		try_io("initialize_domain /\\* from <kernel>", 1);
 		try_io("initialize_domain /foo from <kernel> \\*", 0);
-		try_io("no_initialize_domain /foo", 1);
-		try_io("no_initialize_domain /\\*", 1);
-		try_io("no_initialize_domain /foo /bar", 0);
+		try_io("no_initialize_domain /foo from any", 1);
+		try_io("no_initialize_domain /\\* from any", 1);
+		try_io("no_initialize_domain /foo /bar from any", 0);
 		try_io("no_initialize_domain /foo from /bar", 1);
 		try_io("no_initialize_domain /foo from <kernel> /bar", 1);
 		try_io("no_initialize_domain /\\* from <kernel>", 1);
@@ -186,7 +179,12 @@ static void stage_policy_io_test(void)
 
 int main(int argc, char *argv[])
 {
-	tomoyo_test_init();
+	ccs_test_init();
 	stage_policy_io_test();
+	if (0) { /* To suppress "defined but not used" warnings. */
+		write_domain_policy("", 0);
+		write_exception_policy("", 0);
+		set_profile(0, "");
+	}
 	return 0;
 }
