@@ -3,9 +3,9 @@
  *
  * TOMOYO Linux's utilities.
  *
- * Copyright (C) 2005-2012  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2012/04/14
+ * Version: 2.4.0+   2011/09/29
  *
  * This program is executed automatically by kernel
  * when execution of /sbin/init is requested.
@@ -43,6 +43,7 @@
 static void panic(void)
 {
 	printf("Fatal error while loading policy.\n");
+	fflush(stdout);
 	while (1)
 		sleep(100);
 }
@@ -52,16 +53,19 @@ static void panic(void)
 #define proc_exception_policy "/sys/kernel/security/tomoyo/exception_policy"
 #define proc_domain_policy    "/sys/kernel/security/tomoyo/domain_policy"
 #define proc_profile          "/sys/kernel/security/tomoyo/profile"
-#define proc_meminfo          "/sys/kernel/security/tomoyo/meminfo"
+#define proc_stat             "/sys/kernel/security/tomoyo/stat"
 static const char *profile_name = "default";
-static _Bool tomoyo_noload = 0;
-static _Bool tomoyo_quiet = 0;
+static _Bool ccs_noload = 0;
 static _Bool proc_unmount = 0;
 static _Bool sys_unmount = 0;
 static _Bool security_unmount = 0;
 static _Bool chdir_ok = 0;
 
-static _Bool profile_used[256];
+static struct ns_profile {
+	char *namespace;
+	_Bool profile[256];
+} *ns_profile_list;
+static int ns_profile_list_len = 0;
 static char buffer[8192];
 
 static void check_arg(const char *arg)
@@ -81,16 +85,15 @@ static void check_arg(const char *arg)
 		if (!profile_name)
 			panic();
 	} else if (!strcmp(arg, "TOMOYO_NOLOAD"))
-		tomoyo_noload = 1;
-	else if (!strcmp(arg, "TOMOYO_QUIET"))
-		tomoyo_quiet = 1;
+		ccs_noload = 1;
 }
 
 static void ask_profile(void)
 {
 	static char input[128];
 	while (1) {
-		printf("TOMOYO Linux: Select a profile from "
+		char *ret_ignored;
+		printf("TOMOYO: Select a profile from "
 		       "the following list.\n");
 		if (chdir_ok) {
 			/* Show profiles in policy directory. */
@@ -124,7 +127,7 @@ static void ask_profile(void)
 		profile_name = "";
 		printf("> ");
 		memset(input, 0, sizeof(input));
-		fgets(input, sizeof(input) - 1, stdin);
+		ret_ignored = fgets(input, sizeof(input) - 1, stdin);
 		{
 			char *cp = strchr(input, '\n');
 			if (cp)
@@ -153,9 +156,7 @@ static void ask_profile(void)
 			break;
 		}
 		if (!strcmp(input, "TOMOYO_NOLOAD"))
-			tomoyo_noload = 1;
-		if (!strcmp(input, "TOMOYO_QUIET"))
-			tomoyo_quiet = 1;
+			ccs_noload = 1;
 	}
 }
 
@@ -171,10 +172,11 @@ static void copy_files(const char *src, const char *dest)
 	sfd = open(src, O_RDONLY);
 	if (sfd != EOF) {
 		while (1) {
+			int ret_ignored;
 			int len = read(sfd, buffer, sizeof(buffer));
 			if (len <= 0)
 				break;
-			write(dfd, buffer, len);
+			ret_ignored = write(dfd, buffer, len);
 		}
 		close(sfd);
 	}
@@ -186,18 +188,44 @@ static void scan_used_profile_index(void)
 	static _Bool checked = 0;
 	unsigned int i;
 	FILE *fp;
+	struct ns_profile *ptr = NULL;
 	if (checked)
 		return;
 	checked = 1;
 	fp = fopen(proc_domain_policy, "r");
 	if (!fp)
 		panic();
-	for (i = 0; i < 256; i++)
-		profile_used[i] = 0;
-	while (memset(buffer, 0, sizeof(buffer)),
+	while (memset(buffer, 0, sizeof(buffer)) &&
 	       fgets(buffer, sizeof(buffer) - 1, fp)) {
-		if (sscanf(buffer, "use_profile %u", &i) == 1 && i < 256)
-			profile_used[i] = 1;
+		if (buffer[0] == '<') {
+			char *cp = strchr(buffer, ' ');
+			if (!cp)
+				cp = strchr(buffer, '\n');
+			if (cp)
+				*cp = '\0';
+			ptr = NULL;
+			for (i = 0; i < ns_profile_list_len; i++) {
+				if (strcmp(buffer,
+					   ns_profile_list[i].namespace))
+					continue;
+				ptr = &ns_profile_list[i];
+				break;
+			}
+			if (ptr)
+				continue;
+			ns_profile_list = realloc(ns_profile_list,
+						  sizeof(*ptr) *
+						  (ns_profile_list_len + 1));
+			if (!ns_profile_list)
+				panic();
+			ptr = &ns_profile_list[ns_profile_list_len++];
+			ptr->namespace = strdup(buffer);
+			if (!ptr->namespace)
+				panic();
+			memset(ptr->profile, 0, sizeof(ptr->profile));
+		} else if (ptr && sscanf(buffer, "use_profile %u", &i) == 1 &&
+			   i < 256)
+			ptr->profile[i] = 1;
 	}
 	fclose(fp);
 }
@@ -210,56 +238,33 @@ static void disable_profile(void)
 	if (!fp_out)
 		panic();
 	scan_used_profile_index();
-	for (i = 0; i < 256; i++) {
-		if (!profile_used[i])
-			continue;
-		fprintf(fp_out, "%u-COMMENT=disabled\n", i);
+	for (i = 0; i < ns_profile_list_len; i++) {
+		struct ns_profile *ptr = &ns_profile_list[i];
+		int j;
+		for (j = 0; j < 256; j++) {
+			if (!ptr->profile[j])
+				continue;
+			fprintf(fp_out, "%s %u-COMMENT=disabled\n",
+				ptr->namespace, j);
+		}
 	}
 	fclose(fp_out);
 	fp_in = fopen(proc_profile, "r");
 	fp_out = fopen(proc_profile, "w");
 	if (!fp_in || !fp_out)
 		panic();
-	while (memset(buffer, 0, sizeof(buffer)),
+	while (memset(buffer, 0, sizeof(buffer)) &&
 	       fgets(buffer, sizeof(buffer) - 1, fp_in)) {
-		char *cp = strchr(buffer, '=');
+		char *cp = strstr(buffer, "={ mode=");
 		if (!cp)
 			continue;
-		*cp = '\0';
-		if (!strcmp(buffer, "PROFILE_VERSION"))
-			fprintf(fp_out, "%s=%s\n", buffer, cp + 1);
-		else if (strstr(buffer, "COMMENT"))
-			fprintf(fp_out, "%s=disabled\n", buffer);
-		else
-			fprintf(fp_out, "%s={ mode=disabled }\n", buffer);
+		*(cp + 8) = '\0';
+		fprintf(fp_out, "%sdisabled }\n", buffer);
 	}
 	fclose(fp_in);
 	fclose(fp_out);
 }
 
-static void disable_verbose(void)
-{
-	unsigned int i;
-	FILE *fp = fopen(proc_profile, "w");
-	if (!fp)
-		panic();
-	scan_used_profile_index();
-	fprintf(fp, "PREFERENCE::learning={ verbose=disabled }\n");
-	fprintf(fp, "PREFERENCE::permissive={ verbose=disabled }\n");
-	fprintf(fp, "PREFERENCE::enforcing={ verbose=disabled }\n");
-	for (i = 0; i < 256; i++) {
-		if (!profile_used[i])
-			continue;
-		fprintf(fp, "%u-PREFERENCE::learning={ verbose=disabled }\n",
-			i);
-		fprintf(fp, "%u-PREFERENCE::permissive={ verbose=disabled }\n",
-			i);
-		fprintf(fp, "%u-PREFERENCE::enforcing={ verbose=disabled }\n",
-			i);
-	}
-	fclose(fp);
-}
-
 static void show_domain_usage(void)
 {
 	unsigned int domain = 0;
@@ -267,11 +272,11 @@ static void show_domain_usage(void)
 	FILE *fp = fopen(proc_domain_policy, "r");
 	if (!fp)
 		return;
-	while (memset(buffer, 0, sizeof(buffer)),
+	while (memset(buffer, 0, sizeof(buffer)) &&
 	       fgets(buffer, sizeof(buffer) - 1, fp)) {
-		if (!strncmp(buffer, "<kernel>", 8))
+		if (buffer[0] == '<')
 			domain++;
-		else if (buffer[0] && strcmp(buffer, "use_profile"))
+		else if (buffer[0] > ' ' && strncmp(buffer, "use_", 4))
 			acl++;
 	}
 	fclose(fp);
@@ -281,18 +286,21 @@ static void show_domain_usage(void)
 
 static void show_memory_usage(void)
 {
-	FILE *fp = fopen(proc_meminfo, "r");
+	FILE *fp = fopen(proc_stat, "r");
 	if (!fp)
 		return;
 	while (memset(buffer, 0, sizeof(buffer)) &&
 	       fgets(buffer, sizeof(buffer) - 1, fp)) {
 		unsigned int size;
-		if (sscanf(buffer, "Policy: %u", &size) != 1)
-			continue;
-		printf("%u KB used by policy.\n", (size + 1023) / 1024);
-		break;
+		if (sscanf(buffer, "Shared: %u", &size) == 1)
+			printf("%u KB shared. ", (size + 1023) / 1024);
+		else if (sscanf(buffer, "Private: %u", &size) == 1)
+			printf("%u KB private. ", (size + 1023) / 1024);
+		else if (sscanf(buffer, "Policy: %u", &size) == 1)
+			printf("%u KB used by policy.", (size + 1023) / 1024);
 	}
 	fclose(fp);
+	putchar('\n');
 }
 
 int main(int argc, char *argv[])
@@ -343,9 +351,10 @@ int main(int argc, char *argv[])
 	{
 		char *cp;
 		int i;
+		int ret_ignored;
 		int fd = open("/proc/cmdline", O_RDONLY);
 		memset(buffer, 0, sizeof(buffer));
-		read(fd, buffer, sizeof(buffer) - 1);
+		ret_ignored = read(fd, buffer, sizeof(buffer) - 1);
 		close(fd);
 		cp = strchr(buffer, '\n');
 		if (cp)
@@ -374,14 +383,14 @@ int main(int argc, char *argv[])
 	if (chdir_ok) {
 		if (!strcmp(profile_name, "default")) {
 			if (access("profile.conf", R_OK)) {
-				printf("TOMOYO Linux: Default profile "
+				printf("TOMOYO: Default profile "
 				       "doesn't exist.\n");
 				profile_name = "ask";
 			}
 		} else if (strcmp(profile_name, "ask") &&
 			   strcmp(profile_name, "disable")) {
 			if (access(profile_name, R_OK)) {
-				printf("TOMOYO Linux: Specified profile "
+				printf("TOMOYO: Specified profile "
 				       "doesn't exist.\n");
 				profile_name = "ask";
 			}
@@ -396,23 +405,19 @@ int main(int argc, char *argv[])
 	if (chdir_ok) {
 		copy_files("manager.conf", proc_manager);
 		copy_files("exception_policy.conf", proc_exception_policy);
-		if (!tomoyo_noload)
+		if (!ccs_noload)
 			copy_files("domain_policy.conf", proc_domain_policy);
 		if (!strcmp(profile_name, "default"))
 			copy_files("profile.conf", proc_profile);
 		else if (strcmp(profile_name, "disable"))
 			copy_files(profile_name, proc_profile);
-		copy_files("meminfo.conf", proc_meminfo);
+		copy_files("stat.conf", proc_stat);
 	}
 
 	/* Use disabled mode? */
 	if (!strcmp(profile_name, "disable"))
 		disable_profile();
 
-	/* Disable verbose mode? */
-	if (tomoyo_quiet)
-		disable_verbose();
-
 	/* Do additional initialization. */
 	if (!access("/etc/tomoyo/tomoyo-post-init", X_OK)) {
 		const pid_t pid = fork();
