@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.4.0+   2011/08/20
+ * Version: 2.4.0+   2011/10/25
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -703,6 +703,8 @@ static void make_path_group(void)
 	echo("path_group ANY_PATHNAME \\*:/\\{\\*\\}/");
 	echo("path_group ANY_PATHNAME \\*:/\\{\\*\\}/\\*");
 	echo("path_group ANY_PATHNAME \\*:[\\$]");
+	echo("path_group ANY_PATHNAME "
+	     "socket:[family=\\$:type=\\$:protocol=\\$]");
 	echo("path_group ANY_DIRECTORY /");
 	echo("path_group ANY_DIRECTORY /\\{\\*\\}/");
 	echo("path_group ANY_DIRECTORY \\*:/");
@@ -857,8 +859,6 @@ static const char *reject_log = "yes";
 static unsigned int max_audit_log = 1024;
 /* How many ACL entries to add automatically by learning mode? */
 static unsigned int max_learning_entry = 2048;
-/* How long should we carry sleep penalty? */
-static unsigned int enforcing_penalty = 0;
 
 /**
  * make_profile - Make /etc/tomoyo/policy/current/profile.conf .
@@ -883,29 +883,25 @@ static void make_profile(void)
 		file_only = "::file";
 	fprintf(fp, "PROFILE_VERSION=20100903\n");
 	fprintf(fp, "0-COMMENT=-----Disabled Mode-----\n"
-		"0-PREFERENCE={ max_audit_log=%u max_learning_entry=%u "
-		"enforcing_penalty=%u }\n"
+		"0-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"0-CONFIG%s={ mode=disabled grant_log=%s reject_log=%s }\n",
-		max_audit_log, max_learning_entry, enforcing_penalty,
-		file_only, grant_log, reject_log);
+		max_audit_log, max_learning_entry, file_only, grant_log,
+		reject_log);
 	fprintf(fp, "1-COMMENT=-----Learning Mode-----\n"
-		"1-PREFERENCE={ max_audit_log=%u max_learning_entry=%u "
-		"enforcing_penalty=%u }\n"
+		"1-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"1-CONFIG%s={ mode=learning grant_log=%s reject_log=%s }\n",
-		max_audit_log, max_learning_entry, enforcing_penalty,
-		file_only, grant_log, reject_log);
+		max_audit_log, max_learning_entry, file_only, grant_log,
+		reject_log);
 	fprintf(fp, "2-COMMENT=-----Permissive Mode-----\n"
-		"2-PREFERENCE={ max_audit_log=%u max_learning_entry=%u "
-		"enforcing_penalty=%u }\n"
+		"2-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"2-CONFIG%s={ mode=permissive grant_log=%s reject_log=%s }\n",
-		max_audit_log, max_learning_entry, enforcing_penalty,
-		file_only, grant_log, reject_log);
+		max_audit_log, max_learning_entry, file_only, grant_log,
+		reject_log);
 	fprintf(fp, "3-COMMENT=-----Enforcing Mode-----\n"
-		"3-PREFERENCE={ max_audit_log=%u max_learning_entry=%u "
-		"enforcing_penalty=%u }\n"
+		"3-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"3-CONFIG%s={ mode=enforcing grant_log=%s reject_log=%s }\n",
-		max_audit_log, max_learning_entry, enforcing_penalty,
-		file_only, grant_log, reject_log);
+		max_audit_log, max_learning_entry, file_only, grant_log,
+		reject_log);
 	close_file(fp, 1, "profile.tmp", "profile.conf");
 }
 
@@ -1221,10 +1217,7 @@ static const char editpolicy_data[] =
 "keyword_alias acl_group 253                 = acl_group 253\n"
 "keyword_alias acl_group 254                 = acl_group 254\n"
 "keyword_alias acl_group 255                 = acl_group 255\n"
-"keyword_alias address_group                 = address_group\n"
 "keyword_alias aggregator                    = aggregator\n"
-"keyword_alias capability                    = capability\n"
-"keyword_alias deny_autobind                 = deny_autobind\n"
 "keyword_alias file append                   = file append\n"
 "keyword_alias file chgrp                    = file chgrp\n"
 "keyword_alias file chmod                    = file chmod\n"
@@ -1251,11 +1244,7 @@ static const char editpolicy_data[] =
 "keyword_alias file unmount                  = file unmount\n"
 "keyword_alias file write                    = file write\n"
 "keyword_alias initialize_domain             = initialize_domain\n"
-"keyword_alias ipc signal                    = ipc signal\n"
 "keyword_alias keep_domain                   = keep_domain\n"
-"keyword_alias misc env                      = misc env\n"
-"keyword_alias network inet                  = network inet\n"
-"keyword_alias network unix                  = network unix\n"
 "keyword_alias no_initialize_domain          = no_initialize_domain\n"
 "keyword_alias no_keep_domain                = no_keep_domain\n"
 "keyword_alias no_reset_domain               = no_reset_domain\n"
@@ -1263,10 +1252,6 @@ static const char editpolicy_data[] =
 "keyword_alias path_group                    = path_group\n"
 "keyword_alias quota_exceeded                = quota_exceeded\n"
 "keyword_alias reset_domain                  = reset_domain\n"
-"keyword_alias task auto_domain_transition   = task auto_domain_transition\n"
-"keyword_alias task auto_execute_handler     = task auto_execute_handler\n"
-"keyword_alias task denied_execute_handler   = task denied_execute_handler\n"
-"keyword_alias task manual_domain_transition = task manual_domain_transition\n"
 "keyword_alias transition_failed             = transition_failed\n"
 "keyword_alias use_group                     = use_group\n"
 "keyword_alias use_profile                   = use_profile\n"
@@ -1618,9 +1603,7 @@ int main(int argc, char *argv[])
 			reject_log = arg + 11;
 		} else if (!sscanf(arg, "max_audit_log=%u", &max_audit_log) &&
 			   !sscanf(arg, "max_learning_entry=%u",
-				   &max_learning_entry) &&
-			   !sscanf(arg, "enforcing_penalty=%u",
-				   &enforcing_penalty)) {
+				   &max_learning_entry)) {
 			fprintf(stderr, "Unknown option: '%s'\n", argv[i]);
 			return 1;
 		}
