@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2011/09/29
+ * Version: 2.4.0+   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -24,9 +24,9 @@
 
 int main(int argc, char *argv[])
 {
-	struct tomoyo_domain_policy dp = { NULL, 0, NULL };
-	tomoyo_read_domain_policy(&dp, NULL);
-	tomoyo_write_domain_policy(&dp, 1);
-	tomoyo_clear_domain_policy(&dp);
+	struct ccs_domain_policy dp = { NULL, 0, NULL };
+	ccs_read_domain_policy(&dp, NULL);
+	ccs_write_domain_policy(&dp, 1);
+	ccs_clear_domain_policy(&dp);
 	return 0;
 }
